from setuptools import setup

setup(
    name='nlp_rules',
    version='1.0.3',
    description='an regular tools for nlp classify and ner',
    author='QinHaining',
    author_email='2364839934@qq.com',
    url='https://github.com/scmsqhn/nlp_rules',
    packages=[],
    include_package_data=True,
    install_requires=[],
    license='MIT License',
    zip_safe=False,
)
